class server_bot:
    matnadress = [
        'https://messengerg2c26.iranlms.ir',
        'https://messengerg2c1.iranlms.ir',
        "https://messengerg2c33.iranlms.ir",
        'https://messengerg2c22.iranlms.ir',
        'https://messengerg2c55.iranlms.ir',
        'https://messengerg2c57.iranlms.ir',
        'https://messengerg2c15.iranlms.ir',
        'https://messengerg2c16.iranlms.ir',
        'https://messengerg2c46.iranlms.ir',
        'https://messengerg2c39.iranlms.ir',
        'https://messengerg2c40.iranlms.ir',
        'https://messengerg2c41.iranlms.ir',
        'https://messengerg2c6.iranlms.ir',
        'https://messengerg2c7.iranlms.ir',
        'https://messengerg2c63.iranlms.ir',
        'https://messengerg2c31.iranlms.ir',
        'https://messengerg2c3.iranlms.ir',
        'https://messengerg2c101.iranlms.ir',
        'https://messengerg2c146.iranlms.ir',
        'https://messengerg2c115.iranlms.ir',
        'https://messengerg2c59.iranlms.ir',
        'https://messengerg2c27.iranlms.ir',
        'https://messengerg2c110.iranlms.ir',
        'https://messengerg2c159.iranlms.ir'
    ]

    filesadress = [
        'https://messengerg2c26.iranlms.ir'
        'https://messengerg2c39.iranlms.ir',
        'https://messengerg2c7.iranlms.ir',
        'https://messengerg2c17.iranlms.ir',
        'https://messengerg2c46.iranlms.ir'
    ]
